fix_phone_numbers: Fix up mobile numbers

Description Usage Arguments Details Value

Description

Fixes up mobile numbers to a uniform text format.

Usage

1

Arguments

column

A character vector of numerical string characters.

Details

This format is specific to that used in a given location - for now the function is useful only for Nigeria mobile numbers which come in the format expressed by the regex pattern "^0[7-9][0-1][0-9]{8}$".

Value

An update vector, usually the column of a data frame.


DevSolutionsLtd/NARCcontacts documentation built on May 30, 2019, 6:06 p.m.