rearrange_df: Rearrange data frame columns

Description Usage Arguments Value

Description

Rearranges the columns of data frames to suit the prescribed format. Columns without values are assigned NA.

Usage

1

Arguments

df

An object of class data.frame

hdr

A character vector containing names of outputted data frame appearing in the desired order.

Value

A data frame.


DevSolutionsLtd/NARCcontacts documentation built on May 30, 2019, 6:06 p.m.