Description Usage Arguments Details Value
Fixes up mobile numbers to a uniform text format.
1 | fix_phone_numbers(column)
|
column |
A character vector of numerical string characters. |
This format is specific to that used in a given location - for
now the function is useful only for Nigeria mobile numbers which come in
the format expressed by the regex pattern "^0[7-9][0-1][0-9]{8}$".
An update vector, usually the column of a data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.