Description Usage Arguments Value
Rearranges the columns of data frames to suit the prescribed format. Columns without values are assigned NA.
1 | rearrange_df(df, hdr)
|
df |
An object of class |
hdr |
A character vector containing names of outputted data frame appearing in the desired order. |
A data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.